---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_project_environment_variable Resource - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides a Project Environment Variable resource.
  A Project Environment Variable resource defines an Environment Variable on a Vercel Project.
  For more detailed information, please see the Vercel documentation https://vercel.com/docs/concepts/projects/environment-variables.
  ~> Terraform currently provides both a standalone Project Environment Variable resource (a single Environment Variable), and a Project resource with Environment Variables defined in-line via the environment field.
  At this time you cannot use a Vercel Project resource with in-line environment in conjunction with any vercel_project_environment_variable resources. Doing so will cause a conflict of settings and will overwrite Environment Variables.
---

# vercel_project_environment_variable (Resource)

Provides a Project Environment Variable resource.

A Project Environment Variable resource defines an Environment Variable on a Vercel Project.

For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/concepts/projects/environment-variables).

~> Terraform currently provides both a standalone Project Environment Variable resource (a single Environment Variable), and a Project resource with Environment Variables defined in-line via the `environment` field.
At this time you cannot use a Vercel Project resource with in-line `environment` in conjunction with any `vercel_project_environment_variable` resources. Doing so will cause a conflict of settings and will overwrite Environment Variables.

## Example Usage

```terraform
resource "vercel_project" "example" {
  name = "example-project"

  git_repository = {
    type = "github"
    repo = "vercel/some-repo"
  }
}

# An environment variable that will be created
# for this project for the "production" environment.
resource "vercel_project_environment_variable" "example" {
  project_id = vercel_project.example.id
  key        = "foo"
  value      = "bar"
  target     = ["production"]
}

# An environment variable that will be created
# for this project for the "preview" environment when the branch is "staging".
resource "vercel_project_environment_variable" "example_git_branch" {
  project_id = vercel_project.example.id
  key        = "foo"
  value      = "bar-staging"
  target     = ["preview"]
  git_branch = "staging"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `key` (String) The name of the Environment Variable.
- `project_id` (String) The ID of the Vercel project.
- `target` (Set of String) The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
- `value` (String, Sensitive) The value of the Environment Variable.

### Optional

- `git_branch` (String) The git branch of the Environment Variable.
- `team_id` (String) The ID of the Vercel team.

### Read-Only

- `id` (String) The ID of the Environment Variable.

## Import

Import is supported using the following syntax:

```shell
# If importing into a personal account, or with a team configured on
# the provider, simply use the project_id and environment variable id.
# - project_id can be found in the project `settings` tab in the Vercel UI.
# - environment variable id can be taken from the network tab on the project page.
terraform import vercel_project_environment_variable.example prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/FdT2e1E5Of6Cihmt

# Alternatively, you can import via the team_id, project_id and
# environment variable id.
# - team_id can be found in the team `settings` tab in the Vercel UI.
# - project_id can be found in the project `settings` tab in the Vercel UI.
# - environment variable id can be taken from the network tab on the project page.
terraform import vercel_project_environment_variable.example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/FdT2e1E5Of6Cihmt
```
